@@ -67,9 +67,9 @@ def get_status():
 
         if ref.__class__ in (TrackingBranch, LocalBranch, TrackedBranch):
             if codereview_tag not in [ x.name for x in tags ]:
-                review_commits = len(repo.git('log', '--pretty=format:%H', '%s..%s' % (ref.merge_refspec or '', ref.refspec), split=True))
+                review_commits = len(repo.git('log', '--no-merges', '--pretty=format:%H', '%s..%s' % (ref.merge_refspec or '', ref.refspec), split=True))
             else:
-                review_commits = len(repo.git('log', '--pretty=format:%H', '%s..%s' % (codereview_tag, ref.refspec), split=True))
+                review_commits = len(repo.git('log', '--no-merges', '--pretty=format:%H', '%s..%s' % (codereview_tag, ref.refspec), split=True))
         else:
             review_commits = None
 
@@ -129,7 +129,6 @@ def complete_review():
 
     branch = repo.branch()
     repo.git('tag', '-a', '%s%s' % (TAG_PREFIX, branch), '-f', '-m', 'creating code review for branch %s' % branch)
-    repo.git('push', '--tags')
     print 'Created tag %s%s' % (TAG_PREFIX, branch)
 
 def start_review():
@@ -163,4 +162,3 @@ def update_branches():
         if branch.pull:
             repo.git('checkout', branch.name)
             repo.git('pull')
-
