@@ -12,6 +12,21 @@ except ImportError:
     print 'You should run "pip install termcolor" to fully utilize these utilities.'
     colored_func = disable_colored_func
 
+def supports_color():
+    """
+    Returns True if the running system's terminal supports color, and False
+    otherwise.
+    """
+    unsupported_platform = (sys.platform in ('win32', 'Pocket PC'))
+    # isatty is not always implemented, #6223.
+    is_a_tty = hasattr(sys.stdout, 'isatty') and sys.stdout.isatty()
+    if unsupported_platform or not is_a_tty:
+        return False
+    return True
+
+if not supports_color():
+    colored_func = disable_colored_func
+
 class Colored(object):
     disabled = False
     def __call__(self, *args, **kwargs):
